@@ -16,6 +16,7 @@ import io
 import itertools
 import json
 import os
+import pdb
 import sys
 import csv as csv_std
 import tabulate
@@ -490,8 +491,6 @@ def add_foreign_key(
     Example:
 
         sqlite-utils add-foreign-key my.db books author_id authors id
-
-    WARNING: Could corrupt your database! Back up your database file first.
     """
     db = sqlite_utils.Database(path)
     _load_extensions(db, load_extension)
@@ -2407,6 +2406,14 @@ def schema(
     "--default-none", type=str, multiple=True, help="Remove default from this column"
 )
 @click.option(
+    "add_foreign_keys",
+    "--add-foreign-key",
+    type=(str, str, str),
+    multiple=True,
+    help="Add a foreign key constraint from a column to another table with another column",
+)
+@click.option(
+    "drop_foreign_keys",
     "--drop-foreign-key",
     type=str,
     multiple=True,
@@ -2427,7 +2434,8 @@ def transform(
     pk_none,
     default,
     default_none,
-    drop_foreign_key,
+    add_foreign_keys,
+    drop_foreign_keys,
     sql,
     load_extension,
 ):
@@ -2476,8 +2484,10 @@ def transform(
     elif pk_none:
         kwargs["pk"] = None
     kwargs["defaults"] = default_dict
-    if drop_foreign_key:
-        kwargs["drop_foreign_keys"] = drop_foreign_key
+    if drop_foreign_keys:
+        kwargs["drop_foreign_keys"] = drop_foreign_keys
+    if add_foreign_keys:
+        kwargs["add_foreign_keys"] = add_foreign_keys
 
     if sql:
         for line in db[table].transform_sql(**kwargs):
@@ -2800,7 +2810,6 @@ def _analyze(db, tables, columns, save, common_limit=10, no_most=False, no_least
 @click.option(
     "-e",
     "--editable",
-    type=click.Path(readable=True, exists=True, dir_okay=True, file_okay=False),
     help="Install a project in editable mode from this path",
 )
 def install(packages, upgrade, editable):
@@ -2809,7 +2818,7 @@ def install(packages, upgrade, editable):
     if upgrade:
         args += ["--upgrade"]
     if editable:
-        args += ["--editable", str(editable)]
+        args += ["--editable", editable]
     args += list(packages)
     sys.argv = args
     run_module("pip", run_name="__main__")
@@ -2902,6 +2911,7 @@ def _generate_convert_help():
 @click.option("--drop", is_flag=True, help="Drop original column afterwards")
 @click.option("--no-skip-false", is_flag=True, help="Don't skip falsey values")
 @click.option("-s", "--silent", is_flag=True, help="Don't show a progress bar")
+@click.option("pdb_", "--pdb", is_flag=True, help="Open pdb debugger on first error")
 def convert(
     db_path,
     table,
@@ -2917,6 +2927,7 @@ def convert(
     drop,
     no_skip_false,
     silent,
+    pdb_,
 ):
     sqlite3.enable_callback_tracebacks(True)
     db = sqlite_utils.Database(db_path)
@@ -2969,6 +2980,19 @@ def convert(
         )
         click.echo("Would affect {} row{}".format(count, "" if count == 1 else "s"))
     else:
+        # Wrap fn with a thing that will catch errors and optionally drop into pdb
+        if pdb_:
+            fn_ = fn
+
+            def wrapped_fn(value):
+                try:
+                    return fn_(value)
+                except Exception as ex:
+                    print("\nException raised, dropping into pdb...:", ex)
+                    pdb.post_mortem(ex.__traceback__)
+                    sys.exit(1)
+
+            fn = wrapped_fn
         try:
             db[table].convert(
                 columns,
